CellIndex class Core

Identifies a cell position by its column and row index.

Constructors

CellIndex.indexByColumnRow({required int columnIndex, required int rowIndex})
CellIndex.indexByColumnRow(columnIndex: 0, rowIndex: 0 ); // A1 CellIndex.indexByColumnRow(columnIndex: 0, rowIndex: 1 ); // A2
factory
CellIndex.indexByString(String cellIndex)
CellIndex.indexByString('A1'); // columnIndex: 0, rowIndex: 0 CellIndex.indexByString('A2'); // columnIndex: 0, rowIndex: 1
factory

Properties

cellId String
Avoid using it as it is very process expensive function.
no setter
columnIndex int
The 0-based column index.
final
hashCode int
The hash code for this object.
no setteroverride
rowIndex int
The 0-based row index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override