ChartType enum Charts

The kind of chart to render.

Inheritance
Available extensions

Values

column → const ChartType

A vertical bar (column) chart.

bar → const ChartType

A horizontal bar chart.

line → const ChartType

A line chart.

pie → const ChartType

A pie chart.

doughnut → const ChartType

A doughnut chart.

area → const ChartType

An area chart.

scatter → const ChartType

A scatter (XY) chart.

radar → const ChartType

A radar (spider) chart.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChartType>
A constant List of the values in this enum, in order of their declaration.