rankFromBottom property
For a top10 rule, whether the rule selects the bottom N instead of the
top N.
Implementation
final bool rankFromBottom;
For a top10 rule, whether the rule selects the bottom N instead of the
top N.
final bool rankFromBottom;