CustomNumFormat class sealed Number Formats

Interface for custom (user-defined) number formats.

Implemented types
Implementers

Properties

formatCode String
The Excel format code string that controls how the value is displayed.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(CellValue? value) bool
Whether value can be displayed with this format.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String v) CellValue
Parses the raw stored string v into the CellValue this format represents.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited