Data class Core

Represents a single cell's data within a Sheet.

Contains the cell's value, style, and position information.

Properties

cellIndex → CellIndex
returns the string based cellId as A1, A2 or Z5
no setter
cellStyle ↔ CellStyle?
returns the user-defined CellStyle
getter/setter pair
columnIndex → int
The 0-based column index of this cell.
no setter
comment ↔ Comment?
The comment (note) attached to this cell, or null if there is none.
getter/setter pair
dataValidation ↔ DataValidation?
The data validation keyed to this single cell, or null if there is none.
getter/setter pair
displayText → String
The text a spreadsheet application would show for this cell.
no setter
hashCode → int
The hash code for this object.
no setteroverride
The hyperlink attached to this cell, or null if there is none.
getter/setter pair
rowIndex → int
The 0-based row index of this cell.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetName → String
The name of the sheet containing this cell.
no setter
value ↔ CellValue?
returns the value stored in this cell;
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFormula(String formula) → void
Helps to set the formula
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

newData(Sheet sheet, int row, int column) → Data
Creates an empty Data cell at the given row and column in sheet.