DateCellValue class Cell Values
A cell value containing a date (year, month, day).
Constructors
- DateCellValue({required int year, required int month, required int day})
-
Creates a date cell value from
year,month, andday.const - DateCellValue.fromDateTime(DateTime dt)
- Creates a date cell value from a DateTime.
Properties
- asError → CellErrorValue?
-
This value as a CellErrorValue, or
nullif it is not an error.no setterinherited - day → int
-
The day component (1-31).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isError → bool
-
Whether this value is a cell error (e.g.
#DIV/0!,#N/A).no setterinherited - month → int
-
The month component (1-12).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- year → int
-
The year component.
final
Methods
-
asDateTimeLocal(
) → DateTime - Converts to a local DateTime.
-
asDateTimeUtc(
) → DateTime - Converts to a UTC DateTime.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override