DateTimeCellValue class Cell Values

Excel does not know if this is UTC or not. Use methods asDateTimeLocal or asDateTimeUtc to get the DateTime object you prefer.

Inheritance

Constructors

DateTimeCellValue({required int year, required int month, required int day, required int hour, required int minute, int second = 0, int millisecond = 0, int microsecond = 0})
Creates a date-time cell value.
const
DateTimeCellValue.fromDateTime(DateTime date)
Creates a DateTimeCellValue from a DateTime.

Properties

asError CellErrorValue?
This value as a CellErrorValue, or null if it is not an error.
no setterinherited
day int
The day component (1-31).
final
hashCode int
The hash code for this object.
no setteroverride
hour int
The hour component (0-24).
final
isError bool
Whether this value is a cell error (e.g. #DIV/0!, #N/A).
no setterinherited
microsecond int
The microsecond component (0-1000).
final
millisecond int
The millisecond component (0-1000).
final
minute int
The minute component (0-60).
final
month int
The month component (1-12).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second int
The second component (0-60).
final
year int
The year component.
final

Methods

asDateTimeLocal() DateTime
Converts to a local DateTime.
asDateTimeUtc() DateTime
Converts to a UTC DateTime.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override