DoubleCellValue class Cell Values
A cell value containing a double.
Constructors
- DoubleCellValue(double value)
-
Creates a double cell value.
const
Properties
- asError → CellErrorValue?
-
This value as a CellErrorValue, or
nullif it is not an error.no setterinherited - hashCode → int
-
The hash code for this object.
no setteroverride
- isError → bool
-
Whether this value is a cell error (e.g.
#DIV/0!,#N/A).no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
The double value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override