FormulaCellValue class Cell Values
A cell value containing a formula expression.
Constructors
- FormulaCellValue(String formula, {String? cachedValue})
-
Creates a formula cell value from the given
formulastring, with an optionalcachedValueresult.const
Properties
- asError → CellErrorValue?
-
This value as a CellErrorValue, or
nullif it is not an error.no setterinherited - cachedValue → String?
-
The result Excel last cached for this formula (the cell's
<v>), if any.final - formula → String
-
The formula string (e.g.
SUM(A1:A10)).final - hashCode → int
-
The hash code for this object.
no setteroverride
- isError → bool
-
Whether this value is a cell error (e.g.
#DIV/0!,#N/A).no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override