LegendPosition enum Charts

Where the legend sits, or none to hide it.

Inheritance
Available extensions

Values

Legend on the right of the plot area.

left → const LegendPosition

Legend on the left of the plot area.

top → const LegendPosition

Legend above the plot area.

bottom → const LegendPosition

Legend below the plot area.

none → const LegendPosition

No legend.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LegendPosition>
A constant List of the values in this enum, in order of their declaration.