PaperSize class abstract final

Printer paper sizes, as the codes used by <pageSetup paperSize> (ECMA-376 18.3.1.63). Only the common sizes are named; any other code can still be set via PageSetup.paperSize as a raw int.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

a3 → const int
A3: 297mm × 420mm.
a4 → const int
A4: 210mm × 297mm.
a5 → const int
A5: 148mm × 210mm.
b4 → const int
B4 (JIS): 257mm × 364mm.
b5 → const int
B5 (JIS): 182mm × 257mm.
US Legal: 8.5" × 14".
letter → const int
US Letter: 8.5" × 11".
tabloid → const int
Tabloid / Ledger: 11" × 17".