PivotFunction enum Pivot Tables

The aggregation applied to a pivot-table data field.

Inheritance
Available extensions

Values

sum → const PivotFunction

Sum of the values.

count → const PivotFunction

Count of all values (numeric or not).

average → const PivotFunction

Arithmetic mean of the values.

max → const PivotFunction

Largest value.

min → const PivotFunction

Smallest value.

product → const PivotFunction

Product of the values.

countNumbers → const PivotFunction

Count of the numeric values only.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PivotFunction>
A constant List of the values in this enum, in order of their declaration.