addConditionalFormat method

void addConditionalFormat(
  1. CellIndex start,
  2. CellIndex end,
  3. ConditionalFormat format
)
inherited

Adds a conditional-formatting format over the range from start to end. Multiple rules may target the same or overlapping ranges.

Implementation

void addConditionalFormat(
  CellIndex start,
  CellIndex end,
  ConditionalFormat format,
) {
  final sqref = getSpanCellId(
    start.columnIndex,
    start.rowIndex,
    end.columnIndex,
    end.rowIndex,
  );
  _conditionalFormats.add((sqref, format));
}