defaultColumnWidth property
The default column width, or null if not set.
Implementation
double? get defaultColumnWidth => _defaultColumnWidth;
The default column width, or null if not set.
double? get defaultColumnWidth => _defaultColumnWidth;