protectionAllowed property
The actions permitted while this sheet is protected (read-only view).
Implementation
Set<SheetProtectionOption> get protectionAllowed =>
Set.unmodifiable(_protectionAllow);
The actions permitted while this sheet is protected (read-only view).
Set<SheetProtectionOption> get protectionAllowed =>
Set.unmodifiable(_protectionAllow);