sparklineGroups property

List<SparklineGroup> get sparklineGroups
inherited

The sparkline groups on this sheet, those read from an opened file first, then any added via the API. Read groups are for inspection; they round-trip untouched in the worksheet extLst.

Implementation

List<SparklineGroup> get sparklineGroups =>
    List.unmodifiable([..._parsedSparklineGroups, ..._sparklineGroups]);