SheetVisibility enum Worksheet

Visibility of a worksheet's tab within the workbook.

veryHidden sheets can only be unhidden programmatically (not from Excel's UI). A workbook must keep at least one visible sheet.

Inheritance
Available extensions

Values

visible → const SheetVisibility

The sheet's tab is shown in the workbook.

hidden → const SheetVisibility

The sheet's tab is hidden but can be unhidden from Excel's UI.

veryHidden → const SheetVisibility

The sheet is hidden and can only be unhidden programmatically.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SheetVisibility>
A constant List of the values in this enum, in order of their declaration.