VerticalAlign enum Styling
Vertical alignment of cell content.
Values
- Top → const VerticalAlign
-
Align content to the top of the cell.
- Center → const VerticalAlign
-
Center content vertically within the cell.
- Bottom → const VerticalAlign
-
Align content to the bottom of the cell.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VerticalAlign> - A constant List of the values in this enum, in order of their declaration.