Border class Styling
Represents a border on one side of a cell.
Constructors
- Border({BorderStyle? borderStyle, ExcelColor? borderColorHex})
-
Creates a Border with an optional
borderStyleandborderColorHex.
Properties
- borderColorHex → String?
-
The border color resolved to an
AARRGGBBhex string, ornull.no setter - borderStyle → BorderStyle?
-
The line style of the border, or
nullfor no border.final - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override