BorderStyle enum Styling
Available border line styles in Excel.
Values
- None → const BorderStyle
-
No border line.
const BorderStyle('none') - DashDot → const BorderStyle
-
A dash-dot line.
const BorderStyle('dashDot') - DashDotDot → const BorderStyle
-
A dash-dot-dot line.
const BorderStyle('dashDotDot') - Dashed → const BorderStyle
-
A dashed line.
const BorderStyle('dashed') - Dotted → const BorderStyle
-
A dotted line.
const BorderStyle('dotted') - Double → const BorderStyle
-
A double line.
const BorderStyle('double') - Hair → const BorderStyle
-
A fine hairline.
const BorderStyle('hair') - Medium → const BorderStyle
-
A medium-weight line.
const BorderStyle('medium') - MediumDashDot → const BorderStyle
-
A medium-weight dash-dot line.
const BorderStyle('mediumDashDot') - MediumDashDotDot → const BorderStyle
-
A medium-weight dash-dot-dot line.
const BorderStyle('mediumDashDotDot') - MediumDashed → const BorderStyle
-
A medium-weight dashed line.
const BorderStyle('mediumDashed') - SlantDashDot → const BorderStyle
-
A slanted dash-dot line.
const BorderStyle('slantDashDot') - Thick → const BorderStyle
-
A thick line.
const BorderStyle('thick') - Thin → const BorderStyle
-
A thin line.
const BorderStyle('thin')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → String
-
The OOXML name for this border style.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BorderStyle> - A constant List of the values in this enum, in order of their declaration.