rightBorder property
Border
get
rightBorder
The border drawn on the right side of the cell.
Implementation
Border get rightBorder {
return _rightBorder;
}
set
rightBorder
(Border? rightBorder)
Sets the border drawn on the right side of the cell.
Implementation
set rightBorder(Border? rightBorder) {
_rightBorder = rightBorder ?? Border();
}