PivotDataField class Pivot Tables
A value field in a PivotTable: which source column to aggregate and how.
Constructors
- PivotDataField(int column, {PivotFunction function = PivotFunction.sum, String? name})
-
Creates a data field that aggregates source
columnusingfunction, with an optional captionname.const
Properties
- column → int
-
0-based column index, relative to the source range's first column.
final
- function → PivotFunction
-
The aggregation to apply.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
Optional caption (defaults to e.g. "Sum of
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited