StandardNumericNumFormat class Number Formats

A standard numeric number format with a fixed format ID.

Inheritance
Implemented types

Properties

formatCode String
The Excel format code string that controls how the value is displayed.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
numFmtId int
The built-in Excel format id (numFmtId) of this standard format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accepts(CellValue? value) bool
Whether value can be displayed with this format.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String v) CellValue
Parses the raw stored string v into the CellValue this format represents.
inherited
toString() String
A string representation of this object.
override
writeDouble(DoubleCellValue value) String
Returns the raw string used to store value in the worksheet.
inherited
writeInt(IntCellValue value) String
Returns the raw string used to store value in the worksheet.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited