Core topic
The main entry points for reading, creating, and editing Excel workbooks and worksheets.
Classes
- CellIndex Core
- Identifies a cell position by its column and row index.
- Data Core
- Represents a single cell's data within a Sheet.
- DefinedName Core
- A workbook defined name (a named range, constant, or formula).
- Excel Core
-
The main class for reading, creating, and editing Excel
.xlsxfiles. - Sheet Core
- Represents a single worksheet within an Excel workbook.