Styling topic
Classes and enums for cell styling: fonts, colors, borders, alignment, and text formatting.
Classes
- Border Styling
- Represents a border on one side of a cell.
- CellStyle Styling
- Styling class for cells.
- ExcelColor Styling
- Represents a color value for use in cell styling.
- GradientFill Styling
- A gradient cell fill, a smooth blend between two or more colour stops.
- GradientStop Styling
-
One colour stop of a GradientFill: color placed at position along the
gradient (
0.0= start,1.0= end). A gradient needs at least two stops.
Enums
- BorderStyle Styling
- Available border line styles in Excel.
- ColorType Styling
- Color type category.
- FillPatternType Styling
-
Cell fill pattern.
solidfills the cell with a single colour (the cell style'sbackgroundColor); the other patterns draw a hatch/shade using thebackgroundColoras the pattern colour over an optionalfillBackgroundColor. - FontFamily Styling
- Available font families.
- FontScheme Styling
- Font scheme setting.
- GradientType Styling
- The geometry of a GradientFill.
- HorizontalAlign Styling
- Horizontal alignment of cell content.
- TextWrapping Styling
- Text wrapping mode for cells.
- ThemeColor Styling
-
The twelve document-theme color slots, in the order Excel indexes them in
styles.xml(theme="N"). Use with ExcelColor.theme to author a color that follows the workbook's theme. - Underline Styling
- Text underline style.
- VerticalAlign Styling
- Vertical alignment of cell content.