Styling topic
Classes and enums for cell styling — fonts, colors, borders, alignment, and text formatting.
Classes
Enums
- BorderStyle Styling
- Available border line styles in Excel.
- ColorType Styling
- Color type category.
- FillPatternType Styling
-
Cell fill pattern.
solidfills the cell with a single colour (the cell style'sbackgroundColor); the other patterns draw a hatch/shade using thebackgroundColoras the pattern colour over an optionalfillBackgroundColor. - FontFamily Styling
- Available font families.
- FontScheme Styling
- Font scheme setting.
- HorizontalAlign Styling
- Horizontal alignment of cell content.
- TextWrapping Styling
- Text wrapping mode for cells.
- ThemeColor Styling
-
The twelve document-theme color slots, in the order Excel indexes them in
styles.xml(theme="N"). Use with ExcelColor.theme to author a color that follows the workbook's theme. - Underline Styling
- Text underline style.
- VerticalAlign Styling
- Vertical alignment of cell content.